==> jc-1.4.0.tar.gz: jas/CP.h <==
// public abstract class jas.CP

// class file dependencies
// @dep_class c0e5264359137f3 jas_CP
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_jas_CP_H_
#define _JC_jas_CP_H_

// Forward structure declarations
struct _jc_jas_ClassEnv$object;
struct _jc_java_io_DataOutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_jas_CP$sub_refs	_jc_jas_CP$sub_refs;
typedef struct _jc_jas_CP$sub_nonrefs	_jc_jas_CP$sub_nonrefs;
typedef struct _jc_jas_CP$refs	_jc_jas_CP$refs;
typedef struct _jc_jas_CP$nonrefs	_jc_jas_CP$nonrefs;
typedef struct _jc_jas_CP$object	_jc_jas_CP$object;

typedef const struct _jc_jas_CP$vmethods	_jc_jas_CP$vmethods;
typedef const struct _jc_jas_CP$vtable	_jc_jas_CP$vtable;
typedef const struct _jc_jas_CP$vtype	_jc_jas_CP$vtype;

// Constructors
extern void _jc_jas_CP$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_jas_CP$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_jas_CP$method$getUniq$0f11f9cb5c3ec6cc(_jc_env *, struct _jc_jas_CP$object *);
extern void _jc_jas_CP$method$resolve$f7bbca8128967cc2(_jc_env *, struct _jc_jas_CP$object *, struct _jc_jas_ClassEnv$object *);
extern void _jc_jas_CP$method$write$c5719140f8114b75(_jc_env *, struct _jc_jas_CP$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *);

// Virtual method descriptors
extern _jc_method _jc_jas_CP$method_info$getUniq$0f11f9cb5c3ec6cc;
extern _jc_method _jc_jas_CP$method_info$resolve$f7bbca8128967cc2;
extern _jc_method _jc_jas_CP$method_info$write$c5719140f8114b75;

// Virtual methods structure
struct _jc_jas_CP$vmethods {
	struct _jc_java_lang_String$object	*(*getUniq$0f11f9cb5c3ec6cc)(_jc_env *, struct _jc_jas_CP$object *);
	void	(*resolve$f7bbca8128967cc2)(_jc_env *, struct _jc_jas_CP$object *, struct _jc_jas_ClassEnv$object *);
	void	(*write$c5719140f8114b75)(_jc_env *, struct _jc_jas_CP$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *);
};

// Vtable
struct _jc_jas_CP$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_CP$vmethods	jas_CP;
};

// Vtype
struct _jc_jas_CP$vtype {
	_jc_type			type;
	_jc_jas_CP$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_CP$sub_refs {
	struct _jc_java_lang_String$object	*uniq;
};

// Reference instance fields (object)
struct _jc_jas_CP$refs {
    _jc_jas_CP$sub_refs	jas_CP;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_CP$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_jas_CP$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_CP$sub_nonrefs	jas_CP;
};

// Object instance structure
struct _jc_jas_CP$object {
	_jc_jas_CP$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_CP$vtype	*vtype;
	_jc_jas_CP$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_CP$vtype _jc_jas_CP$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_CP, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_CP$class_object;

#endif	/* _JC_jas_CP_H_ */

==> jc-1.4.6.tar.gz: jas/CP.h <==
// public abstract class jas.CP

// class file dependencies
// @dep_class c0e5264359137f3 jas_CP
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_jas_CP_H_
#define _JC_jas_CP_H_

// Forward structure declarations
struct _jc_jas_ClassEnv$object;
struct _jc_java_io_DataOutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_jas_CP$sub_refs	_jc_jas_CP$sub_refs;
typedef struct _jc_jas_CP$sub_nonrefs	_jc_jas_CP$sub_nonrefs;
typedef struct _jc_jas_CP$refs	_jc_jas_CP$refs;
typedef struct _jc_jas_CP$nonrefs	_jc_jas_CP$nonrefs;
typedef struct _jc_jas_CP$object	_jc_jas_CP$object;

typedef const struct _jc_jas_CP$vmethods	_jc_jas_CP$vmethods;
typedef const struct _jc_jas_CP$vtable	_jc_jas_CP$vtable;
typedef const struct _jc_jas_CP$vtype	_jc_jas_CP$vtype;

// Constructors
extern void _jc_jas_CP$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_jas_CP$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_jas_CP$method$getUniq$0f11f9cb5c3ec6cc(_jc_env *, struct _jc_jas_CP$object *) _JC_JCNI_ATTR;
extern void _jc_jas_CP$method$resolve$f7bbca8128967cc2(_jc_env *, struct _jc_jas_CP$object *, struct _jc_jas_ClassEnv$object *) _JC_JCNI_ATTR;
extern void _jc_jas_CP$method$write$c5719140f8114b75(_jc_env *, struct _jc_jas_CP$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_jas_CP$method_info$getUniq$0f11f9cb5c3ec6cc;
extern _jc_method _jc_jas_CP$method_info$resolve$f7bbca8128967cc2;
extern _jc_method _jc_jas_CP$method_info$write$c5719140f8114b75;

// Virtual methods structure
struct _jc_jas_CP$vmethods {
	struct _jc_java_lang_String$object	*(*getUniq$0f11f9cb5c3ec6cc)(_jc_env *, struct _jc_jas_CP$object *) _JC_JCNI_ATTR;
	void	(*resolve$f7bbca8128967cc2)(_jc_env *, struct _jc_jas_CP$object *, struct _jc_jas_ClassEnv$object *) _JC_JCNI_ATTR;
	void	(*write$c5719140f8114b75)(_jc_env *, struct _jc_jas_CP$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_jas_CP$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_CP$vmethods	jas_CP;
};

// Vtype
struct _jc_jas_CP$vtype {
	_jc_type			type;
	_jc_jas_CP$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_CP$sub_refs {
	struct _jc_java_lang_String$object	*uniq;
};

// Reference instance fields (object)
struct _jc_jas_CP$refs {
    _jc_jas_CP$sub_refs	jas_CP;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_CP$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_jas_CP$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_CP$sub_nonrefs	jas_CP;
};

// Object instance structure
struct _jc_jas_CP$object {
	_jc_jas_CP$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_CP$vtype	*vtype;
	_jc_jas_CP$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_CP$vtype _jc_jas_CP$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_CP, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_CP$class_object;

#endif	/* _JC_jas_CP_H_ */
